import { useRef, useState, useEffect } from 'react';
/* eslint-disable no-param-reassign */

function clearTooltipTimers() {
  var timers = [];

  for (var _i = 0; _i < arguments.length; _i++) {
    timers[_i] = arguments[_i];
  }

  timers.forEach(function (t) {
    clearTimeout(t.current);
    t.current = null;
  });
}

var delayValues = {
  medium: 375,
  long: 1000
};

function useTooltipVisibility(mouseEnterDelay, mouseOutDelay, interactive) {
  var timerToShow = useRef(null);
  var timerToHide = useRef(null);

  var _a = useState(false),
      isVisible = _a[0],
      setIsVisible = _a[1];

  function updateVisibility(newValue, timer, delay) {
    if (delay === 'none') {
      setIsVisible(newValue);
    } else {
      timer.current = setTimeout(function () {
        return setIsVisible(newValue);
      }, delayValues[delay]);
    }
  }

  function handleTriggerMouseOver() {
    clearTooltipTimers(timerToShow, timerToHide);
    if (!isVisible) updateVisibility(true, timerToShow, mouseEnterDelay);
  }

  function handleMouseLeave() {
    clearTooltipTimers(timerToShow, timerToHide);
    if (isVisible) updateVisibility(false, timerToHide, mouseOutDelay);
  }

  function handleTooltipMouseEnter() {
    if (interactive) {
      clearTooltipTimers(timerToHide);
    }
  }

  useEffect(function () {
    // cleanup on unmount
    return function () {
      return clearTooltipTimers(timerToShow, timerToHide);
    };
  }, []);
  return [isVisible, handleTriggerMouseOver, handleTooltipMouseEnter, handleMouseLeave];
}

export { useTooltipVisibility };
//# sourceMappingURL=useTooltipVisibility.js.map
